.. project-template documentation master file, created by
   sphinx-quickstart on Mon Jan 18 14:44:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to elpigraph-python's documentation!
============================================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting Started

   quick_start
   
.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: User guide

   user_guide

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation

   api

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Tutorial - Examples

   auto_examples/index 
   
   
Credits and references

`Getting started <quick_start.html>`_
-------------------------------------

How to install the package and a quick start example.

`User guide <user_guide.html>`_
-------------------------------

An introduction to the concept of Elastic Principal Graphs and the organization of this package.

`API Documentation <api.html>`_
-------------------------------

The layout of available classes and functions.

`Examples <auto_examples/index.html>`_
--------------------------------------

A set of examples. It complements the `User Guide <user_guide.html>`_.


